This is an automated email from the git hooks/post-receive script.

Git pushed a commit to branch master
in repository ffmpeg.

commit 1e3883df9f009b457c53a2e83d0955b4bb8b4ca6
Author:     Kacper Michajłow <[email protected]>
AuthorDate: Fri May 29 19:17:32 2026 +0200
Commit:     James Almer <[email protected]>
CommitDate: Sun May 31 03:43:29 2026 +0000

    avformat: rename AVStreamGroupLCEVC to AVStreamGroupLayeredVideo
    
    It will be reused for other similar groups.
    
    Signed-off-by: Kacper Michajłow <[email protected]>
---
 doc/APIchanges         |  4 ++++
 libavformat/avformat.h | 32 ++++++++++++++++++++++++--------
 libavformat/version.h  |  2 +-
 3 files changed, 29 insertions(+), 9 deletions(-)

diff --git a/doc/APIchanges b/doc/APIchanges
index 0f602c9635..a5b24ef43d 100644
--- a/doc/APIchanges
+++ b/doc/APIchanges
@@ -2,6 +2,10 @@ The last version increases of all libraries were on 2025-03-28
 
 API changes, most recent first:
 
+2026-05-xx - xxxxxxxxxx - lavf 62.19.100 - avformat.h
+  Add AVStreamGroupLayeredVideo
+  Add AVStreamGroup.params.layered_video
+
 2026-05-xx - xxxxxxxxxx - lavc 62.35.100 - packet.h
   Add AV_PKT_DATA_HEVC_CONF side data type.
 
diff --git a/libavformat/version.h b/libavformat/version.h
index 6a80f3ac4e..be8ce01160 100644
--- a/libavformat/version.h
+++ b/libavformat/version.h
@@ -32,7 +32,7 @@
 #include "version_major.h"
 
 #define LIBAVFORMAT_VERSION_MINOR  18
-#define LIBAVFORMAT_VERSION_MICRO 100
+#define LIBAVFORMAT_VERSION_MICRO 101
 
 #define LIBAVFORMAT_VERSION_INT AV_VERSION_INT(LIBAVFORMAT_VERSION_MAJOR, \
                                                LIBAVFORMAT_VERSION_MINOR, \

_______________________________________________
ffmpeg-cvslog mailing list -- [email protected]
To unsubscribe send an email to [email protected]

Reply via email to
diff --git a/libavformat/avformat.h b/libavformat/avformat.h
index 0c5df18066..f4c5326f54 100644
--- a/libavformat/avformat.h
+++ b/libavformat/avformat.h
@@ -1065,19 +1065,27 @@ typedef struct AVStreamGroupTileGrid {
 } AVStreamGroupTileGrid;
 
 /**
  * AVStreamGroupLCEVC is meant to define the relation between video streams
  * and a data stream containing LCEVC enhancement layer NALUs.
  *
- * No more than one stream of
- * @ref AVCodecParameters.codec_id "codec_id" AV_CODEC_ID_LCEVC shall be 
present.
+ * The enhancement layer stream is identified by @ref el_index.
  */
-typedef struct AVStreamGroupLCEVC {
+typedef struct AVStreamGroupLayeredVideo {
     const AVClass *av_class;
 
     /**
-     * Index of the LCEVC data stream in AVStreamGroup.
+     * Index of the enhancement layer stream in AVStreamGroup.
      */
-    unsigned int lcevc_index;
+    union {
+        unsigned int el_index;
+        /**
+         * Alias for @ref el_index, kept for backward compatibility.
+         */
+        unsigned int lcevc_index;
+    };
     /**
      * Width of the final stream for presentation.
      */
@@ -1086,7 +1094,14 @@ typedef struct AVStreamGroupLCEVC {
      * Height of the final image for presentation.
      */
     int height;
-} AVStreamGroupLCEVC;
+} AVStreamGroupLayeredVideo;
+
+/**
+ * Alias kept for backward compatibility.
+ *
+ * AVStreamGroupLCEVC was renamed to @ref AVStreamGroupLayeredVideo.
+ */
+#define AVStreamGroupLCEVC AVStreamGroupLayeredVideo
 
 /**
  * AVStreamGroupTREF is meant to define the relation between video, audio,
@@ -1152,6 +1167,7 @@ typedef struct AVStreamGroup {
         struct AVIAMFAudioElement *iamf_audio_element;
         struct AVIAMFMixPresentation *iamf_mix_presentation;
         struct AVStreamGroupTileGrid *tile_grid;
+        struct AVStreamGroupLayeredVideo *layered_video;
         struct AVStreamGroupLCEVC *lcevc;
         struct AVStreamGroupTREF *tref;
     } params;
@@ -1065,19 +1065,27 @@ typedef struct AVStreamGroupTileGrid {
 
 /**
- * AVStreamGroupLCEVC is meant to define the relation between video streams
- * and a data stream containing LCEVC enhancement layer NALUs.
+ * AVStreamGroupLayeredVideo is meant to define the relation between a base
+ * layer video stream and a separate enhancement layer stream that together
+ * form a single layered video presentation (for example a video stream and a
+ * data stream containing LCEVC enhancement layer NALUs, or Dolby Vision
+ * Profile 7 dual-layer encoding).
  *